# odp2md

**odp2md** extracts presentation data from ODP files and converts it to [pandoc](https://pandoc.org) markdown. This allows conversion to [reveal.js](https://revealjs.com) and [Beamer](https://ctan.org/pkg/beamer). It was developed to rescue my lecture notes and slide decks, which resided in huge piles of documents made in PowerPoint and LibreOffice.

# Install

## From Source

```
pip install .
```

## From PyPi

```
pip install odp2md
```


## ToDo

- [x] Normalize text output, which needs to remove trailing spaces which are generated by the hierarchy level
- [ ] detect formulas and convert them into proper pandoc Math/inline Math format
- [ ] detect WMF or other obscure formats and use imagemagick or ffmpeg to convert them
- [x] rename media files with a derivative of the slide title


## Copyright and License

&copy; 2019-2021 Hartmut Seichter

This software is licensed under the terms of the GPLv3. Please consult [LICENSE.md](LICENSE.md)

